@@ -1,7 +1,7 @@
 import subprocess
 import signal
 
-from cpm.domain import cmake
+from cpm.domain import cmake_builder
 
 CMAKELISTS = 'CMakeLists.txt'
 BUILD_DIRECTORY = f'build'
@@ -30,60 +30,61 @@ class CMakeRecipe(object):
             self.filesystem.create_directory(BUILD_DIRECTORY)
 
     def build_cmakelists(self, project):
-        cmake_builder = cmake.a_cmake() \
+        builder = cmake_builder.a_cmake() \
             .minimum_required('3.7') \
             .project(project.name) \
             .include(project.include_directories)
 
-        self.__generate_build_rules(cmake_builder, project)
+        self.__generate_build_rules(builder, project)
 
-        self.__generate_test_rules(cmake_builder, project)
+        self.__generate_test_rules(builder, project)
 
-        return cmake_builder.contents
+        return builder.contents
 
-    def __generate_test_rules(self, cmake_builder, project):
+    def __generate_test_rules(self, builder, project):
         self.test_executables = [test_file.split('/')[-1].split('.')[0] for test_file in project.tests]
-
         if self.test_executables:
             sources_without_main = self._sources_without_main(project)
             if sources_without_main:
                 project_object_library = project.name + '_object_library'
-                cmake_builder.add_object_library(project_object_library, sources_without_main)
+                builder.add_object_library(project_object_library, sources_without_main)
                 object_libraries = [project_object_library]
             else:
                 object_libraries = []
             for executable, test_file in zip(self.test_executables, project.tests):
-                cmake_builder.add_executable(executable, [test_file], object_libraries) \
+                builder.add_executable(executable, [test_file] + project.test_sources, object_libraries) \
                     .set_target_properties(executable, 'COMPILE_FLAGS', ['-std=c++11', '-g'])
                 bits_with_sources = list(filter(lambda p: p.sources, project.bits))
-                if project.link_options.libraries:
-                    link_libraries = [bit.name for bit in bits_with_sources] + project.link_options.libraries
-                    cmake_builder.target_link_libraries(executable, link_libraries)
-            cmake_builder.add_custom_target('test', 'echo "> Done', self.test_executables)
+                link_libraries = [bit.name for bit in bits_with_sources] + project.link_options.libraries
+                if link_libraries:
+                    builder.target_link_libraries(executable, link_libraries)
+                if project.test_include_directories:
+                    builder.target_include_directories(executable, project.test_include_directories)
+            builder.add_custom_target('tests', 'echo "> Done', self.test_executables)
 
-    def __generate_build_rules(self, cmake_builder, project):
+    def __generate_build_rules(self, builder, project):
         for package in project.packages:
             if package.cflags:
-                cmake_builder.set_source_files_properties(package.sources, 'COMPILE_FLAGS', package.cflags)
+                builder.set_source_files_properties(package.sources, 'COMPILE_FLAGS', package.cflags)
         for bit in project.bits:
-            self.__generate_bit_build_rules(cmake_builder, bit)
-        cmake_builder.add_executable(project.name, project.sources)
+            self.__generate_bit_build_rules(builder, bit)
+        builder.add_executable(project.name, project.sources)
         if project.compile_flags:
-            cmake_builder.set_target_properties(project.name, 'COMPILE_FLAGS', project.compile_flags)
-        self.__generate_link_libraries_rule(cmake_builder, project)
+            builder.set_target_properties(project.name, 'COMPILE_FLAGS', project.compile_flags)
+        self.__generate_link_libraries_rule(builder, project)
 
-    def __generate_link_libraries_rule(self, cmake_builder, project):
+    def __generate_link_libraries_rule(self, builder, project):
         bits_with_sources = list(filter(lambda p: p.sources, project.bits))
         if project.link_options.libraries or bits_with_sources:
             link_libraries = [bit.name for bit in bits_with_sources] + project.link_options.libraries
-            cmake_builder.target_link_libraries(project.name, link_libraries)
+            builder.target_link_libraries(project.name, link_libraries)
 
-    def __generate_bit_build_rules(self, cmake_builder, bit):
+    def __generate_bit_build_rules(self, builder, bit):
         if bit.sources:
-            cmake_builder.add_static_library(bit.name, bit.sources)
+            builder.add_static_library(bit.name, bit.sources)
         for package in bit.packages:
             if package.cflags:
-                cmake_builder.set_source_files_properties(package.sources, 'COMPILE_FLAGS', package.cflags)
+                builder.set_source_files_properties(package.sources, 'COMPILE_FLAGS', package.cflags)
 
     def _sources_without_main(self, project):
         return list(filter(lambda x: x != "main.cpp", project.sources))
@@ -99,7 +100,7 @@ class CMakeRecipe(object):
 
     def build_tests(self):
         self.run_compile_command(self.CMAKE_COMMAND, '-G', 'Ninja', '..')
-        self.run_compile_command('ninja', 'test')
+        self.run_compile_command('ninja', 'tests')
 
     def run_all_tests(self):
         self.run_tests(self.test_executables)
