@@ -1,3 +1,4 @@
+import os
 from cpm.domain.bit_loader import BitLoader
 from cpm.domain.project import ProjectAction
 from cpm.domain.project import Package
@@ -20,10 +21,15 @@ class ProjectLoader(object):
             project.version = description.get('version', "0.1")
             project.add_sources(['main.cpp'])
             project.declared_bits = description.get('bits', {})
+            project.declared_test_bits = description.get('test_bits', {})
             for package in self.project_packages(description):
                 project.add_package(package)
                 project.add_include_directory(self.filesystem.parent_directory(package.path))
                 project.add_sources(package.sources)
+            for package in self.project_test_packages(description):
+                project.add_test_package(package)
+                project.add_test_include_directory(self.filesystem.parent_directory(package.path))
+                project.add_test_sources(package.sources)
             project.add_tests(self.test_suites())
             for target in self.described_targets(description):
                 project.add_target(target)
@@ -47,7 +53,7 @@ class ProjectLoader(object):
         return []
 
     def load_local_bits(self):
-        bit_directories = self.filesystem.list_directories('bits')
+        bit_directories = self.filesystem.list_directories(f'{os.getcwd()}/bits')
         return [self.bit_loader.load_from(f'bits/{directory}') for directory in bit_directories]
 
     def load_bits(self, description):
@@ -61,6 +67,11 @@ class ProjectLoader(object):
             yield self.load_package(package, description['packages'][package])
         return []
 
+    def project_test_packages(self, description):
+        for package in description.get('test_packages', []):
+            yield self.load_package(package, description['test_packages'][package])
+        return []
+
     def load_package(self, package, package_description):
         cflags = package_description.get('cflags', []) if package_description is not None else []
         sources = self.all_sources(package)
