@@ -231,7 +231,34 @@ class TestCMakeRecipe(unittest.TestCase):
             'add_library(DeathStarBackend_object_library OBJECT source.cpp)\n'
             'add_executable(test_suite tests/test_suite.cpp $<TARGET_OBJECTS:DeathStarBackend_object_library>)\n'
             'set_target_properties(test_suite PROPERTIES COMPILE_FLAGS "-std=c++11 -g")\n'
-            'add_custom_target(test\n'
+            'add_custom_target(tests\n'
+            '    COMMAND echo "> Done"\n'
+            '    DEPENDS test_suite\n'
+            ')\n'
+        )
+
+    def test_recipe_generation_with_one_test_suite_and_one_bit_and_no_link_libraries(self):
+        filesystem = self.filesystemMockWithoutRecipeFiles()
+        project = _project_with_one_bit('DeathStarBackend', ['bit.cpp'])
+        project.tests = ['tests/test_suite.cpp']
+        cmake_recipe = CMakeRecipe(filesystem)
+
+        cmake_recipe.generate(project)
+
+        filesystem.create_directory.assert_called_once_with('build')
+        filesystem.create_file.assert_called_once_with(
+            'CMakeLists.txt',
+
+            'cmake_minimum_required (VERSION 3.7)\n'
+            'project(DeathStarBackend)\n'
+            'include_directories()\n'
+            'add_library(cest STATIC bit.cpp)\n'
+            'add_executable(DeathStarBackend main.cpp)\n'
+            'target_link_libraries(DeathStarBackend cest)\n'
+            'add_executable(test_suite tests/test_suite.cpp)\n'
+            'set_target_properties(test_suite PROPERTIES COMPILE_FLAGS "-std=c++11 -g")\n'
+            'target_link_libraries(test_suite cest)\n'
+            'add_custom_target(tests\n'
             '    COMMAND echo "> Done"\n'
             '    DEPENDS test_suite\n'
             ')\n'
@@ -259,7 +286,7 @@ class TestCMakeRecipe(unittest.TestCase):
             'add_executable(test_suite tests/test_suite.cpp)\n'
             'set_target_properties(test_suite PROPERTIES COMPILE_FLAGS "-std=c++11 -g")\n'
             'target_link_libraries(test_suite cest boost)\n'
-            'add_custom_target(test\n'
+            'add_custom_target(tests\n'
             '    COMMAND echo "> Done"\n'
             '    DEPENDS test_suite\n'
             ')\n'
@@ -286,7 +313,7 @@ class TestCMakeRecipe(unittest.TestCase):
             'set_target_properties(test_suite_1 PROPERTIES COMPILE_FLAGS "-std=c++11 -g")\n'
             'add_executable(test_suite_2 tests/test_suite_2.cpp $<TARGET_OBJECTS:DeathStarBackend_object_library>)\n'
             'set_target_properties(test_suite_2 PROPERTIES COMPILE_FLAGS "-std=c++11 -g")\n'
-            'add_custom_target(test\n'
+            'add_custom_target(tests\n'
             '    COMMAND echo "> Done"\n'
             '    DEPENDS test_suite_1 test_suite_2\n'
             ')\n'
@@ -315,7 +342,7 @@ class TestCMakeRecipe(unittest.TestCase):
             'add_executable(test_suite tests/test_suite.cpp $<TARGET_OBJECTS:DeathStarBackend_object_library>)\n'
             'set_target_properties(test_suite PROPERTIES COMPILE_FLAGS "-std=c++11 -g")\n'
             'target_link_libraries(test_suite pthread rt)\n'
-            'add_custom_target(test\n'
+            'add_custom_target(tests\n'
             '    COMMAND echo "> Done"\n'
             '    DEPENDS test_suite\n'
             ')\n'
@@ -339,12 +366,65 @@ class TestCMakeRecipe(unittest.TestCase):
             'add_executable(Cest main.cpp)\n'
             'add_executable(test_cest tests/test_cest.cpp)\n'
             'set_target_properties(test_cest PROPERTIES COMPILE_FLAGS "-std=c++11 -g")\n'
-            'add_custom_target(test\n'
+            'add_custom_target(tests\n'
             '    COMMAND echo "> Done"\n'
             '    DEPENDS test_cest\n'
             ')\n'
         )
 
+    def test_recipe_generation_with_one_test_suite_and_test_include_directories(self):
+        filesystem = self.filesystemMockWithoutRecipeFiles()
+        project = _project_with_sources('DeathStarBackend', ['source.cpp'])
+        project.test_include_directories = ['mocks', 'fakes']
+        project.tests = ['tests/test_suite.cpp']
+        cmake_recipe = CMakeRecipe(filesystem)
+
+        cmake_recipe.generate(project)
+
+        filesystem.create_directory.assert_called_once_with('build')
+        filesystem.create_file.assert_called_once_with(
+            'CMakeLists.txt',
+
+            'cmake_minimum_required (VERSION 3.7)\n'
+            'project(DeathStarBackend)\n'
+            'include_directories()\n'
+            'add_executable(DeathStarBackend main.cpp source.cpp)\n'
+            'add_library(DeathStarBackend_object_library OBJECT source.cpp)\n'
+            'add_executable(test_suite tests/test_suite.cpp $<TARGET_OBJECTS:DeathStarBackend_object_library>)\n'
+            'set_target_properties(test_suite PROPERTIES COMPILE_FLAGS "-std=c++11 -g")\n'
+            'target_include_directories(test_suite PUBLIC mocks fakes)\n'
+            'add_custom_target(tests\n'
+            '    COMMAND echo "> Done"\n'
+            '    DEPENDS test_suite\n'
+            ')\n'
+        )
+
+    def test_recipe_generation_with_one_test_suite_and_test_sources(self):
+        filesystem = self.filesystemMockWithoutRecipeFiles()
+        project = _project_with_sources('DeathStarBackend', ['source.cpp'])
+        project.test_sources = ['mocks/mock.cpp', 'mocks/fake.cpp']
+        project.tests = ['tests/test_suite.cpp']
+        cmake_recipe = CMakeRecipe(filesystem)
+
+        cmake_recipe.generate(project)
+
+        filesystem.create_directory.assert_called_once_with('build')
+        filesystem.create_file.assert_called_once_with(
+            'CMakeLists.txt',
+
+            'cmake_minimum_required (VERSION 3.7)\n'
+            'project(DeathStarBackend)\n'
+            'include_directories()\n'
+            'add_executable(DeathStarBackend main.cpp source.cpp)\n'
+            'add_library(DeathStarBackend_object_library OBJECT source.cpp)\n'
+            'add_executable(test_suite tests/test_suite.cpp mocks/mock.cpp mocks/fake.cpp $<TARGET_OBJECTS:DeathStarBackend_object_library>)\n'
+            'set_target_properties(test_suite PROPERTIES COMPILE_FLAGS "-std=c++11 -g")\n'
+            'add_custom_target(tests\n'
+            '    COMMAND echo "> Done"\n'
+            '    DEPENDS test_suite\n'
+            ')\n'
+        )
+
     def test_recipe_is_updated_when_recipe_files_are_found(self):
         filesystem = self.filesystemMockWithRecipeFiles()
         project = _project_without_sources('DeathStarBackend')
@@ -407,7 +487,7 @@ class TestCMakeRecipe(unittest.TestCase):
                 cwd='build'
             ),
             call(
-                ['ninja', 'test'],
+                ['ninja', 'tests'],
                 cwd='build'
             )
         ])
