@@ -103,7 +103,70 @@ class TestInstallService(unittest.TestCase):
             call('cest', '1.0'),
             call('fakeit', '1.0'),
         ])
-        bit_installer.install.assert_has_calls([
-            call(bit_download),
-            call(bit_download)
+
+    def test_it_installs_test_bits_declared_in_project(self):
+        project_loader = MagicMock()
+        cpm_hub_connector = MagicMock()
+        bit_installer = MagicMock()
+        bit_download = MagicMock()
+        project = Project('Project')
+        project.declared_test_bits = {
+            'cest': '1.0',
+            'fakeit': '1.0',
+        }
+        project_loader.load.return_value = project
+        cpm_hub_connector.download_bit.return_value = bit_download
+        service = InstallService(project_loader, bit_installer, cpm_hub_connector)
+
+        service.install_project_bits()
+
+        cpm_hub_connector.download_bit.assert_has_calls([
+            call('cest', '1.0'),
+            call('fakeit', '1.0'),
+        ])
+
+    def test_it_does_not_install_bit_that_is_already_installed(self):
+        project_loader = MagicMock()
+        cpm_hub_connector = MagicMock()
+        bit_installer = MagicMock()
+        project = Project('Project')
+        project.add_bit(Bit('cest', '1.0'))
+        project_loader.load.return_value = project
+        service = InstallService(project_loader, bit_installer, cpm_hub_connector)
+
+        service.install('cest', '1.0')
+
+        cpm_hub_connector.download_bit.assert_not_called()
+
+    def test_it_upgrades_bit_that_is_already_installed_to_a_newer_version(self):
+        project_loader = MagicMock()
+        cpm_hub_connector = MagicMock()
+        bit_installer = MagicMock()
+        project = Project('Project')
+        project.add_bit(Bit('cest', '1.0'))
+        project_loader.load.return_value = project
+        service = InstallService(project_loader, bit_installer, cpm_hub_connector)
+
+        service.install('cest', '1.1')
+
+        cpm_hub_connector.download_bit.assert_called_once_with('cest', '1.1')
+
+    def test_it_installs_bit_transitive_dependencies(self):
+        project_loader = MagicMock()
+        cpm_hub_connector = MagicMock()
+        bit_installer = MagicMock()
+        bit_download = MagicMock()
+        chromos_bit = Bit('chromos', version='1.0')
+        chromos_bit.declared_bits = {'zeromq': '4.3.2'}
+        bit_installer.install.side_effect = [chromos_bit, Bit('zeromq', version='4.3.2')]
+        project = Project('Project')
+        project_loader.load.return_value = project
+        cpm_hub_connector.download_bit.return_value = bit_download
+        service = InstallService(project_loader, bit_installer, cpm_hub_connector)
+
+        service.install('chromos', '1.0')
+
+        cpm_hub_connector.download_bit.assert_has_calls([
+            call('chromos', '1.0'),
+            call('zeromq', '4.3.2'),
         ])
