@@ -1,7 +1,8 @@
 import unittest
-
 import mock
 
+import os
+
 from cpm.domain.bit import Bit
 from cpm.domain.project import Package, ProjectAction
 from cpm.domain.project_loader import NotAChromosProject
@@ -81,6 +82,24 @@ class TestProjectLoader(unittest.TestCase):
             'cest': '1.0'
         }
 
+    def test_loading_project_with_one_declared_test_bit(self):
+        yaml_handler = mock.MagicMock()
+        filesystem = mock.MagicMock()
+        yaml_handler.load.return_value = {
+            'name': 'Project',
+            'test_bits': {
+                'cest': '1.0'
+            }
+        }
+        loader = ProjectLoader(yaml_handler, filesystem)
+
+        loaded_project = loader.load()
+
+        assert loaded_project.name == 'Project'
+        assert loaded_project.declared_test_bits == {
+            'cest': '1.0'
+        }
+
     def test_loading_project_with_one_package(self):
         yaml_handler = mock.MagicMock()
         filesystem = mock.MagicMock()
@@ -216,7 +235,7 @@ class TestProjectLoader(unittest.TestCase):
         bits = loader.load_local_bits()
 
         assert bits == []
-        filesystem.list_directories.assert_called_once_with('bits')
+        filesystem.list_directories.assert_called_once_with(f'{os.getcwd()}/bits')
 
     @mock.patch('cpm.domain.project_loader.BitLoader')
     def test_loading_local_bits_when_bits_directory_contains_one_bit(self, BitLoader):
@@ -232,7 +251,7 @@ class TestProjectLoader(unittest.TestCase):
         bits = loader.load_local_bits()
 
         assert bits == [Bit('cest')]
-        filesystem.list_directories.assert_called_once_with('bits')
+        filesystem.list_directories.assert_called_once_with(f'{os.getcwd()}/bits')
         bit_loader.load_from.assert_called_once_with('bits/cest')
 
     @mock.patch('cpm.domain.project_loader.BitLoader')
@@ -249,7 +268,7 @@ class TestProjectLoader(unittest.TestCase):
         bits = loader.load_local_bits()
 
         assert bits == [Bit('cest'), Bit('base64')]
-        filesystem.list_directories.assert_called_once_with('bits')
+        filesystem.list_directories.assert_called_once_with(f'{os.getcwd()}/bits')
         bit_loader.load_from.assert_has_calls([
             mock.call('bits/cest'),
             mock.call('bits/base64')
@@ -271,3 +290,19 @@ class TestProjectLoader(unittest.TestCase):
         assert loaded_project.name == 'Project'
         assert loaded_project.actions == [ProjectAction('deploy', 'sudo make me a sandwich')]
 
+    def test_loading_project_with_one_test_package(self):
+        yaml_handler = mock.MagicMock()
+        filesystem = mock.MagicMock()
+        filesystem.find.return_value = []
+        filesystem.parent_directory.return_value = '.'
+        yaml_handler.load.return_value = {
+            'name': 'Project',
+            'test_packages': {'mocks': None},
+        }
+        loader = ProjectLoader(yaml_handler, filesystem)
+
+        project = loader.load()
+
+        assert project.name == 'Project'
+        assert Package(path='mocks') in project.test_packages
+        assert project.test_include_directories == ['.']
